@@ -1,5 +1,6 @@
 from __future__ import print_function
 
+from total_ordering import total_ordering
 from contextlib import contextmanager
 import unittest
 import sys
@@ -19,6 +20,7 @@ else:
             return result
         return result[:_MAX_LENGTH] + ' [truncated]...'
 
+@total_ordering
 class DelfickError(Exception):
     """Helpful class for creating custom exceptions"""
     desc = ""
@@ -37,6 +39,12 @@ class DelfickError(Exception):
             message = "{0}\nerrors:\n\t{1}".format(message, "\n\t".join(str(error) for error in self.errors))
         return message
 
+    def __unicode__(self):
+        return str(self).decode("utf-8")
+
+    def __repr__(self):
+        return "{0}({1}, {2}, _errors={3})".format(self.__class__.__name__, self.message, ', '.join("{0}={1}".format(k, v) for k, v in self.kwargs.items()), self.errors)
+
     def oneline(self):
         """Get back the error as a oneliner"""
         desc = self.desc
@@ -69,7 +77,10 @@ class DelfickError(Exception):
 
     def __eq__(self, error):
         """Say whether this error is like the other error"""
-        return error.__class__ == self.__class__ and error.message == self.message and error.kwargs == self.kwargs
+        return error.__class__ == self.__class__ and error.message == self.message and error.kwargs == self.kwargs and sorted(self.errors) == sorted(error.errors)
+
+    def __lt__(self, error):
+        return (self.__class__.__name__, self.message, sorted(self.kwargs.items()), self.errors) < (error.__class__.__name__, error.message, sorted(error.kwargs.items()), error.errors)
 
 class ProgrammerError(Exception):
     """For when the programmer should have prevented something happening"""
@@ -165,3 +176,19 @@ class DelfickErrorTestMixin:
             msg = '%s: %r not found in %r' % (msg, expected_regex.pattern, text)
             raise self.failureException(msg)
 
+    def assertIs(self, expr1, expr2, msg=None):
+        """For Python2.6 compatibility"""
+        spr = None
+        if type(DelfickErrorTestMixin) is type:
+            spr = super(DelfickErrorTestMixin, self)
+
+        if spr and hasattr(spr, "assertIs"):
+            return spr.assertIs(self, expr1, expr2, msg)
+        else:
+            if expr1 is not expr2:
+                standardMsg = '%s is not %s' % (safe_repr(expr1), safe_repr(expr2))
+                if hasattr(self, "_formatMessage"):
+                    self.fail(self._formatMessage(msg, standardMsg))
+                else:
+                    self.fail(msg or standardMsg)
+
